@@ -56,6 +56,13 @@ class KBugReportPrivate
 public:
     KBugReportPrivate(KBugReport *q): q(q), m_aboutData(KAboutData::applicationData()) {}
 
+    enum BugDestination
+    {
+        BugsKdeOrg,
+        CustomEmail,
+        CustomUrl
+    };
+
     void _k_slotConfigureEmail();
     void _k_slotSetFrom();
     void _k_appChanged(int);
@@ -88,7 +95,7 @@ public:
             }
         return -1;
     }
-    bool submitBugWeb;
+    BugDestination bugDestination;
 };
 
 KBugReport::KBugReport(const KAboutData &aboutData, QWidget *_parent)
@@ -102,12 +109,19 @@ KBugReport::KBugReport(const KAboutData &aboutData, QWidget *_parent)
     connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
 
     d->m_aboutData = aboutData;
-    d->m_process = 0;
-    d->submitBugWeb = false;
+    d->m_process = nullptr;
+    d->bugDestination = KBugReportPrivate::CustomEmail;
 
-    if (d->m_aboutData.bugAddress() == QStringLiteral("submit@bugs.kde.org")) {
+    const QString bugAddress = d->m_aboutData.bugAddress();
+    if (bugAddress == QStringLiteral("submit@bugs.kde.org")) {
         // This is a core KDE application -> redirect to the web form
-        d->submitBugWeb = true;
+        d->bugDestination = KBugReportPrivate::BugsKdeOrg;
+    } else if (!QUrl(bugAddress).scheme().isEmpty()) {
+        // The bug reporting address is a URL -> redirect to that
+        d->bugDestination = KBugReportPrivate::CustomUrl;
+    }
+
+    if (d->bugDestination != KBugReportPrivate::CustomEmail) {
         KGuiItem::assign(buttonBox->button(QDialogButtonBox::Cancel), KStandardGuiItem::close());
     }
 
@@ -125,7 +139,7 @@ KBugReport::KBugReport(const KAboutData &aboutData, QWidget *_parent)
 
     int row = 0;
 
-    if (!d->submitBugWeb) {
+    if (d->bugDestination == KBugReportPrivate::CustomEmail) {
         // From
         QString qwtstr = i18n("Your email address. If incorrect, use the Configure Email button to change it");
         tmpLabel = new QLabel(i18nc("Email sender address", "From:"), this);
@@ -157,8 +171,8 @@ KBugReport::KBugReport(const KAboutData &aboutData, QWidget *_parent)
                                   i18n("Send this bug report to %1.", d->m_aboutData.bugAddress())));
         row++;
     } else {
-        d->m_configureEmail = 0;
-        d->m_from = 0;
+        d->m_configureEmail = nullptr;
+        d->m_from = nullptr;
     }
 
     // Program name
@@ -200,7 +214,7 @@ KBugReport::KBugReport(const KAboutData &aboutData, QWidget *_parent)
     }
     d->kde_version = QStringLiteral(KXMLGUI_VERSION_STRING);
     d->kde_version += QStringLiteral(", ") + QLatin1String(XMLGUI_DISTRIBUTION_TEXT);
-    if (!d->submitBugWeb) {
+    if (d->bugDestination != KBugReportPrivate::BugsKdeOrg) {
         d->m_strVersion += QLatin1Char(' ') + d->kde_version;
     }
     d->m_version = new QLabel(d->m_strVersion, this);
@@ -223,7 +237,7 @@ KBugReport::KBugReport(const KAboutData &aboutData, QWidget *_parent)
     tmpLabel->setTextInteractionFlags(Qt::TextBrowserInteraction);
     glay->addWidget(tmpLabel, row, 1, 1, 2);
 
-    if (!d->submitBugWeb) {
+    if (d->bugDestination == KBugReportPrivate::CustomEmail) {
         // Severity
         d->m_bgSeverity = new QGroupBox(i18n("Se&verity"), this);
         static const char *const sevNames[5] = { "critical", "grave", "normal", "wishlist", "i18n" };
@@ -275,10 +289,19 @@ KBugReport::KBugReport(const KAboutData &aboutData, QWidget *_parent)
     } else {
         // Point to the web form
 
+        QString text;
+        if (d->bugDestination == KBugReportPrivate::BugsKdeOrg) {
+            text = i18n("<qt>To submit a bug report, click on the button below. This will open a web browser "
+                        "window on <a href=\"https://bugs.kde.org\">https://bugs.kde.org</a> where you will find "
+                        "a form to fill in. The information displayed above will be transferred to that server.</qt>");
+            d->_k_updateUrl();
+        } else {
+            text = i18n("<qt>To submit a bug report, click on the button below. This will open a web browser "
+                        "window on <a href=\"%1\">%2</a>.</qt>", bugAddress, bugAddress);
+            d->url = QUrl(bugAddress);
+        }
+
         lay->addSpacing(10);
-        QString text = i18n("<qt>To submit a bug report, click on the button below. This will open a web browser "
-                            "window on <a href=\"http://bugs.kde.org\">http://bugs.kde.org</a> where you will find "
-                            "a form to fill in. The information displayed above will be transferred to that server.</qt>");
         QLabel *label = new QLabel(text, this);
         label->setOpenExternalLinks(true);
         label->setTextInteractionFlags(Qt::LinksAccessibleByMouse | Qt::LinksAccessibleByKeyboard);
@@ -288,10 +311,12 @@ KBugReport::KBugReport(const KAboutData &aboutData, QWidget *_parent)
 
         d->appcombo->setFocus();
 
-        d->_k_updateUrl();
-
         QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
-        okButton->setText(i18n("&Launch Bug Report Wizard"));
+        if (d->bugDestination == KBugReportPrivate::BugsKdeOrg) {
+            okButton->setText(i18n("&Launch Bug Report Wizard"));
+        } else {
+            okButton->setText(i18n("&Submit Bug Report"));
+        }
         okButton->setIcon(QIcon::fromTheme(QStringLiteral("tools-report-bug")));
     }
 
@@ -306,7 +331,7 @@ KBugReport::~KBugReport()
 
 QString KBugReport::messageBody() const
 {
-    if (!d->submitBugWeb) {
+    if (d->bugDestination == KBugReportPrivate::CustomEmail) {
         return d->m_lineedit->toPlainText();
     } else {
         return QString();
@@ -315,7 +340,7 @@ QString KBugReport::messageBody() const
 
 void KBugReport::setMessageBody(const QString &messageBody)
 {
-    if (!d->submitBugWeb) {
+    if (d->bugDestination == KBugReportPrivate::CustomEmail) {
         d->m_lineedit->setPlainText(messageBody);
     }
 }
@@ -346,7 +371,7 @@ void KBugReportPrivate::_k_appChanged(int i)
     if (index > 0) {
         appName = appName.left(index);
     }
-    //qDebug() << "appName " << appName;
+    //qCDebug(DEBUG_KXMLGUI) << "appName " << appName;
 
     QString strDisplayVersion; //Version string to show in the UI
     if (appname == appName && !m_aboutData.version().isEmpty()) {
@@ -357,13 +382,13 @@ void KBugReportPrivate::_k_appChanged(int i)
         strDisplayVersion = i18nc("unknown program name", "unknown");
     }
 
-    if (!submitBugWeb) {
+    if (bugDestination != KBugReportPrivate::BugsKdeOrg) {
         m_strVersion += QLatin1Char(' ') + kde_version;
         strDisplayVersion += QLatin1Char(' ') + kde_version;
     }
 
     m_version->setText(strDisplayVersion);
-    if (submitBugWeb) {
+    if (bugDestination == KBugReportPrivate::BugsKdeOrg) {
         _k_updateUrl();
     }
 }
@@ -375,11 +400,11 @@ void KBugReportPrivate::_k_slotConfigureEmail()
     }
     m_process = new QProcess;
     QObject::connect(m_process, SIGNAL(finished(int,QProcess::ExitStatus)), q, SLOT(_k_slotSetFrom()));
-    m_process->start(QStringLiteral("kcmshell5"), QStringList() << QStringLiteral("kcm_useraccount"));
+    m_process->start(QStringLiteral("kcmshell5"), QStringList() << QStringLiteral("user_manager"));
     if (!m_process->waitForStarted()) {
-        //qDebug() << "Couldn't start kcmshell5..";
+        //qCDebug(DEBUG_KXMLGUI) << "Couldn't start kcmshell5..";
         delete m_process;
-        m_process = 0;
+        m_process = nullptr;
         return;
     }
     m_configureEmail->setEnabled(false);
@@ -388,7 +413,7 @@ void KBugReportPrivate::_k_slotConfigureEmail()
 void KBugReportPrivate::_k_slotSetFrom()
 {
     delete m_process;
-    m_process = 0;
+    m_process = nullptr;
     m_configureEmail->setEnabled(true);
 
     KEMailSettings emailSettings;
@@ -406,7 +431,7 @@ void KBugReportPrivate::_k_slotSetFrom()
 
 void KBugReport::accept()
 {
-    if (d->submitBugWeb) {
+    if (d->bugDestination != KBugReportPrivate::CustomEmail) {
         QDesktopServices::openUrl(d->url);
         return;
     }
@@ -450,7 +475,7 @@ void KBugReport::accept()
     if (!sendBugReport()) {
         QString msg = i18n("Unable to send the bug report.\n"
                            "Please submit a bug report manually....\n"
-                           "See http://bugs.kde.org/ for instructions.");
+                           "See https://bugs.kde.org/ for instructions.");
         KMessageBox::error(this, msg + QStringLiteral("\n\n") + d->lastError);
         return;
     }
@@ -462,7 +487,8 @@ void KBugReport::accept()
 
 void KBugReport::closeEvent(QCloseEvent *e)
 {
-    if (!d->submitBugWeb && ((d->m_lineedit->toPlainText().length() > 0) || d->m_subject->isModified())) {
+    if (d->bugDestination == KBugReportPrivate::CustomEmail &&
+        ((d->m_lineedit->toPlainText().length() > 0) || d->m_subject->isModified())) {
         int rc = KMessageBox::warningYesNo(this,
                                            i18n("Close and discard\nedited message?"),
                                            i18n("Close Message"), KStandardGuiItem::discard(), KStandardGuiItem::cont());
@@ -476,7 +502,7 @@ void KBugReport::closeEvent(QCloseEvent *e)
 
 QString KBugReport::text() const
 {
-    //qDebug() << d->severityButtons[d->currentSeverity()]->objectName();
+    //qCDebug(DEBUG_KXMLGUI) << d->severityButtons[d->currentSeverity()]->objectName();
     // Prepend the pseudo-headers to the contents of the mail
     QString severity = d->severityButtons[d->currentSeverity()]->objectName();
     QString appname = d->appcombo->currentText();
@@ -531,7 +557,7 @@ bool KBugReport::sendBugReport()
     QStringList args;
     args << QStringLiteral("--subject") << d->m_subject->text() << QStringLiteral("--recipient") << recipient;
     proc.start(command, args);
-    //qDebug() << command << args;
+    //qCDebug(DEBUG_KXMLGUI) << command << args;
     if (!proc.waitForStarted()) {
         qCritical() << "Unable to open a pipe to " << command << endl;
         return false;
@@ -540,7 +566,7 @@ bool KBugReport::sendBugReport()
     proc.closeWriteChannel();
 
     proc.waitForFinished();
-    //qDebug() << "kbugreport: sendbugmail exit, status " << proc.exitStatus() << " code " << proc.exitCode();
+    //qCDebug(DEBUG_KXMLGUI) << "kbugreport: sendbugmail exit, status " << proc.exitStatus() << " code " << proc.exitCode();
 
     QByteArray line;
     if (proc.exitStatus() == QProcess::NormalExit && proc.exitCode() != 0) {
